Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(970)

Unified Diff: src/gpu/GrDrawTarget.h

Issue 597323002: Split GrDrawState and GrOptDrawState into separate classes and remove base class. (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: More nits Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/gpu/GrDrawState.cpp ('k') | src/gpu/GrOptDrawState.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/gpu/GrDrawTarget.h
diff --git a/src/gpu/GrDrawTarget.h b/src/gpu/GrDrawTarget.h
index 8ffc68162799d6d45701f4661763058da2bd4a44..dd2224bdbdd49f8cd5f5dde6ee331245a512cc68 100644
--- a/src/gpu/GrDrawTarget.h
+++ b/src/gpu/GrDrawTarget.h
@@ -694,8 +694,8 @@ public:
virtual DrawToken getCurrentDrawToken() { return DrawToken(this, 0); }
protected:
- // Extend access to GrRODrawState::convertToPEndeingExec to subclasses.
- void convertDrawStateToPendingExec(GrRODrawState* ds) {
+ // Extend access to GrDrawState::convertToPEndeingExec to subclasses.
+ void convertDrawStateToPendingExec(GrDrawState* ds) {
ds->convertToPendingExec();
}
« no previous file with comments | « src/gpu/GrDrawState.cpp ('k') | src/gpu/GrOptDrawState.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698